@@ -52,6 +52,7 @@ typedef struct _GpaModuleInfo GpaModuleInfo;
 struct _GpaModuleInfo {
 	GPAList *  (*printer_list_append) 
 	(GPAList *printers, const gchar* path);
+	GPAList *printers;
 };
 
 static void gpa_printer_class_init (GPAPrinterClass *klass);
@@ -144,21 +145,18 @@ gpa_printer_load_data (GPAPrinter *printer)
 
 	g_return_if_fail (printer->module_path != NULL);
 
-	if ((handle = g_module_open (printer->module_path, 
-				      G_MODULE_BIND_LAZY)) &&
+	if ((handle = printer->module_handle) != NULL &&
 	     g_module_symbol (handle, "gpa_module_init", 
 			      (gpointer*) &init) &&
 	     g_module_symbol (handle, "gpa_module_load_data", 
 			      (gpointer*) &load_data)) {
 		if (init (&info))
 			load_data (printer);
+		printer->module_handle = handle;
 	} else
 		g_warning ("gpa_module_load_data cannot be retrieved from "
 			   "module %s", printer->module_path);
 
-	if (handle)
-		g_module_close (handle);
-
 	return;
 }
 
@@ -488,6 +486,7 @@ GPAList *
 gpa_printer_list_load (void)
 {
 	GPAList *printers;
+	GPANode *p;
 
 	if (gpa_root && gpa_root->printers != NULL) {
 		g_warning ("gpa_printer_list_load should only be called once");
@@ -505,6 +504,11 @@ gpa_printer_list_load (void)
 		return NULL;
 	}
 
+	p = gpa_node_get_child (GPA_NODE (printers), NULL);
+	while (p) {
+		gpa_printer_get_default_settings (GPA_PRINTER (p));
+		p = gpa_node_get_child (GPA_NODE (printers), p);
+	}
 	gpa_list_reverse (printers);
 
 	return printers;
@@ -566,6 +570,24 @@ gpa_printer_get_by_id (const guchar *id)
 	return child;
 }
 
+void
+gpa_printer_set_polling (GPAPrinter *printer, gboolean poll)
+{
+	void (*set_polling) (GPAPrinter *printer, gboolean poll);
+	
+	if (!printer->module_handle)
+		return;
+
+	if (printer->polling == poll)
+		return;
+	
+	if (!g_module_symbol (printer->module_handle, "gpa_module_polling", 
+			      (gpointer*) &set_polling))
+		return;
+	set_polling (printer, poll);
+	printer->polling = poll;
+}
+
 /**
  * gpa_printer_get_default_settings:
  * @printer: 
@@ -621,8 +643,10 @@ gpa_printer_new_stub (const gchar *id, const gchar *name,
 	printer = (GPAPrinter *) gpa_node_new (GPA_TYPE_PRINTER, id);
 	printer->name     = g_strdup (name);
 
-	if (path != NULL)
+	if (path != NULL) {
 		printer->module_path = g_strdup (path);
+		printer->module_handle = g_module_open (path, G_MODULE_BIND_LAZY);
+	}
 	printer->is_complete = FALSE;
 
 	return (GPANode *) printer;	
@@ -633,6 +657,7 @@ gpa_printer_complete_stub (GPAPrinter *printer,
 			   GPAModel *model, GPASettings *settings)
 {
 	GPAList *list;
+	GPAList *state;
 
 	g_return_val_if_fail (printer->is_complete != TRUE, FALSE);
 	g_return_val_if_fail (model != NULL, FALSE);
@@ -642,11 +667,15 @@ gpa_printer_complete_stub (GPAPrinter *printer,
 	g_return_val_if_fail (gpa_initialized (), FALSE);
 
 	list = gpa_list_new (GPA_TYPE_SETTINGS, "Settings", TRUE);
+	state = gpa_list_new (GPA_TYPE_NODE, "State", TRUE);
 	
 	printer->model    = gpa_node_attach (GPA_NODE (printer),
 					     GPA_NODE (gpa_reference_new (GPA_NODE (model), "Model")));
 	printer->settings = gpa_node_attach (GPA_NODE (printer),
 					     GPA_NODE (list));
+	printer->state = gpa_node_attach (GPA_NODE (printer),
+					  GPA_NODE (state));
+
 	printer->is_complete = TRUE;
 
 	gpa_node_reverse_children (GPA_NODE (printer));
@@ -682,10 +711,8 @@ GPANode *
 gpa_printer_new (const gchar *id, const gchar *name, GPAModel *model, GPASettings *settings)
 {
 	GPAPrinter *printer;
-	GPANode *check;
-	GPAList *list;
 
-	printer = gpa_printer_new_stub (id, name, NULL);
+	printer = GPA_PRINTER (gpa_printer_new_stub (id, name, NULL));
 	if (printer == NULL)
 		return NULL;
 	
@@ -722,7 +749,37 @@ gpa_printer_get_settings_by_id (GPAPrinter *printer, const guchar *id)
 	while (child) {
 		if (GPA_NODE_ID_COMPARE (child, id))
 			break;
-		child = gpa_node_get_child (child, NULL);
+		child = gpa_node_get_child (printer->settings, child);
+	}
+	if (child)
+		gpa_node_ref (child);
+	
+	return child;
+}
+
+GPANode *
+gpa_printer_get_state (GPAPrinter *printer)
+{
+	return printer->state;
+}
+
+GPANode *
+gpa_printer_get_state_by_id (GPAPrinter *printer, const guchar *id)
+{
+	GPANode *child;
+
+	g_return_val_if_fail (printer != NULL, NULL);
+	g_return_val_if_fail (GPA_IS_PRINTER (printer), NULL);
+	g_return_val_if_fail (id && id[0], NULL);
+
+	gpa_printer_load_data (printer);
+
+	g_assert (printer->state);
+	child = gpa_node_get_child (printer->state, NULL);
+	while (child) {
+		if (GPA_NODE_ID_COMPARE (child, id))
+			break;
+		child = gpa_node_get_child (printer->state, child);
 	}
 	if (child)
 		gpa_node_ref (child);
